@@ -22,9 +22,10 @@
 #
 # Bacula is a registered trademark of Kern Sibbald.
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 import os
+import sys
 import stat
 import errno
 import copy
@@ -139,14 +140,14 @@ class FileSystem(Fuse) :
         self._initialized = False
         
         # default option values
-        self.logging = 'warning'
+        self.logging = 'info'
         self.syslog = False
         self.driver = 'sqlite3'
         self.database = None
         self.host = 'localhost'
         self.port = 0
         self.username = 'bacula'
-        self.password = ''
+        self.password = None
         self.conf = '/etc/bacula/bacula-sd.conf'
         self.client = ''
         self.fileset = None
@@ -317,11 +318,12 @@ class FileSystem(Fuse) :
         volumes = [[volume[1],   # 0-Volume
                     volume[2],   # 1-MediaType
                     self.device, # 2-Device
-                    jobs[0][1],  # 3-VolSessionId
-                    jobs[0][2],  # 4-VolSessionTime
-                    (volume[5] << 32) | volume[7], # 5-VolAddr: StartAddr
-                    (volume[6] << 32) | volume[8], # 6-VolAddr: EndAddr
-                    fileindex]   # 7-FileIndex
+                    jobs[0][0],  # 3-JobId
+                    jobs[0][1],  # 4-VolSessionId
+                    jobs[0][2],  # 5-VolSessionTime
+                    (volume[5] << 32) | volume[7], # 6-VolAddr: StartAddr
+                    (volume[6] << 32) | volume[8], # 7-VolAddr: EndAddr
+                    fileindex]   # 8-FileIndex
                    for volume in self.catalog.volumes
                    if (volume[0] == jobid and 
                        volume[3] <= fileindex and
@@ -410,6 +412,7 @@ class FileSystem(Fuse) :
             i = child.expect([self.fail_pattern, pexpect.EOF],
                              timeout=None,
                              searchwindowsize=200)
+            self.logfile.flush(flush_tail = True)
             if i == 0 :
                 # count retries
                 if missing == child.match.groups()[0] :
@@ -456,22 +459,22 @@ class FileSystem(Fuse) :
         return items grouped by volume
         '''
         # group volumes
-        vols = []
+        volumes = []
         for item in items :
             for v in item[-1] :
                 found = False
                 findex = v[-1]
-                for vindex in xrange(0,len(vols)) :
-                    volume = vols[vindex]
+                for vindex in xrange(0,len(volumes)) :
+                    volume = volumes[vindex]
                     if not any(map(cmp, v[:-1], volume[:-1])) :
                         volume[-1].append(findex)
                         found = True
                         break
                 if not found :
-                    vols.append(v[:-1] + [[v[-1]]])
+                    volumes.append(v[:-1] + [[v[-1]]])
                     
         # compact list of file indices 
-        for volume in vols :
+        for volume in volumes :
             volume[-1] = list(set(volume[-1]))
             volume[-1].sort()
             l = len(volume[-1])
@@ -488,19 +491,9 @@ class FileSystem(Fuse) :
 
         # reorder volumes to ensure correct handling of
         # files spanning multiple volumes
-        volumes = []
-        vl = len(vols)
-        for vi in xrange(0, vl) :
-            found = False
-            for vj in xrange(vi-1, -1, -1) :
-                if (volumes[vj][3] == vols[vi][3] and
-                    volumes[vj][4] == vols[vi][4] and
-                    volumes[vj][7][-1][-1] == vols[vi][7][0][0]) :
-                    volumes.insert(vj+1, vols[vi])
-                    found = True
-                    break
-            if not found :
-                volumes.append(vols[vi])
+        volumes.sort(cmp = lambda a,b : \
+                         (cmp(a[3],b[3]) or 
+                          cmp(a[8][-1][-1], b[8][0][0])))
 
         return volumes
         
@@ -514,15 +507,15 @@ class FileSystem(Fuse) :
             os.write(bsrfd, 'Volume="%s"\n' % volume[0])
             os.write(bsrfd, 'MediaType="%s"\n' % volume[1])
             os.write(bsrfd, 'Device="%s"\n' % volume[2]) 
-            os.write(bsrfd, 'VolSessionId=%d\n' % volume[3])
-            os.write(bsrfd, 'VolSessionTime=%d\n' % volume[4])
-            os.write(bsrfd, 'VolAddr=%d-%d\n' % (volume[5],volume[6]))
-            for findex in volume[7] :
+            os.write(bsrfd, 'VolSessionId=%d\n' % volume[4])
+            os.write(bsrfd, 'VolSessionTime=%d\n' % volume[5])
+            os.write(bsrfd, 'VolAddr=%d-%d\n' % (volume[6],volume[7]))
+            for findex in volume[8] :
                 if findex[0] == findex[1] :
                     os.write(bsrfd, 'FileIndex=%d\n' % findex[0])
                 else :
                     os.write(bsrfd, 'FileIndex=%d-%d\n' % findex)
-            os.write(bsrfd, 'Count=%d\n' % volume[8])
+            os.write(bsrfd, 'Count=%d\n' % volume[9])
         os.close(bsrfd)
         return bsrpath
 
@@ -678,9 +671,9 @@ class FileSystem(Fuse) :
         if npf > 0 :
             self.logger.info('Prefetching %d objects ... ' % npf)
             self._extract(prefetches)
-        self.logger.info('Cache directory is: %s' % self.cache_prefix)
+        self.logger.debug('Cache directory is: %s' % self.cache_prefix)
         self.joblist = ' '.join([str(job[0]) for job in self.catalog.jobs])
-        self.logger.info('Jobs in file system: %s' % self.joblist)
+        self.logger.debug('Job ids in file system: %s' % self.joblist)
         self.logger.info('BaculaFS ready (%d files).' % len(files))
         
         self._initialized = True
@@ -871,7 +864,7 @@ BaculaFS: exposes the Bacula catalog and storage as a Filesystem in USErspace
     server.parser.add_option(mountopt="username", metavar="USERNAME", default=server.username,
                              help="database user name [default: %default]")
     server.parser.add_option(mountopt="password", metavar="PASSWORD", default=server.password,
-                             help="database password")
+                             help="database password (use '-o password= ' to get a password prompt)")
     server.parser.add_option(mountopt="conf", metavar="PATH", default=server.conf,
                              help="storage daemon configuration file [default: %default]")
     server.parser.add_option(mountopt="client", metavar="CLIENT", default=server.client,
